==> haskell-fast-logger-2.4.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-fast-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 2.4.1
id: fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
key: fastl_E3TDCkJbdvVC2QTgnCq9Ek
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A fast logging system
description:
    A fast logging system
category: System
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.File
hidden-modules: System.Log.FastLogger.IO
                System.Log.FastLogger.IORef System.Log.FastLogger.LogStr
                System.Log.FastLogger.Logger
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/fast-logger-2.4.1
hs-libraries: HSfast-logger-2.4.1-E3TDCkJbdvVC2QTgnCq9Ek
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-2.4.1-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-fast-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 2.4.1
id: fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
key: fastl_4Y7hJzyaWK4EQNfvf2ODm9
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A fast logging system
description:
    A fast logging system
category: System
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.File
hidden-modules: System.Log.FastLogger.IO
                System.Log.FastLogger.IORef System.Log.FastLogger.LogStr
                System.Log.FastLogger.Logger
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/fast-logger-2.4.1
hs-libraries: HSfast-logger-2.4.1-4Y7hJzyaWK4EQNfvf2ODm9
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
